
CREATE SEQUENCE "common_id" start 100 increment 1 maxvalue 2147483647 minvalue 100 cache 1; 
CREATE SEQUENCE "cyber_ecole_id" start 1 increment 1 maxvalue 99 minvalue 1 cache 1; 

/* -------------------------------------------------------- 
  Table structure for table "alias" 
-------------------------------------------------------- */
CREATE TABLE "alias" (
   "id" int4 NOT NULL,
   "alias" varchar(30) NOT NULL,
   "modif" bool,
   "nouveau" bool,
   "delete" bool,
   "tovalid" bool,
   PRIMARY KEY ("alias")
);
CREATE INDEX "alias_alias_key" ON "alias" ("alias");


/* -------------------------------------------------------- 
  Table structure for table "classes" 
-------------------------------------------------------- */
CREATE TABLE "classes" (
   "id" int4 DEFAULT nextval('common_id'::text) NOT NULL,
   "nom" varchar(30) NOT NULL,
   "modif" bool,
   "nouveau" bool,
   "delete" bool,
   "tovalid" bool,
   PRIMARY KEY ("id")
);
CREATE INDEX "id_classes_key" ON "classes" ("id");
CREATE INDEX "nom_classes_key" ON "classes" ("nom");


/* -------------------------------------------------------- 
  Table structure for table "groups" 
-------------------------------------------------------- */
CREATE TABLE "groups" (
   "userid" int4 NOT NULL,
   "classeid" int4 NOT NULL,
   "modif" bool,
   "nouveau" bool,
   "delete" bool,
   "tovalid" bool,
   "primary" bool
);
CREATE INDEX "userid_groups_key" ON "groups" ("userid");
CREATE INDEX "classeid_groups_key" ON "groups" ("classeid");
CREATE INDEX "primary_groups_key" ON "groups" ("userid");


/* -------------------------------------------------------- 
  Table structure for table "users" 
-------------------------------------------------------- */
CREATE TABLE "users" (
   "id" int4 DEFAULT nextval('common_id'::text) NOT NULL,
   "nom" varchar(30) NOT NULL,
   "prenom" varchar(30) NOT NULL,
   "code" varchar(32),
   "infos" varchar(60),
   "login" varchar(8) NOT NULL,
   "passwd" varchar(8) NOT NULL,
   "modif" bool,
   "nouveau" bool,
   "delete" bool,
   "tovalid" bool,
   UNIQUE ("login"),
   PRIMARY KEY ("id")
);

CREATE INDEX "id_users_key" ON "users" ("id");
CREATE INDEX "nom_users_key" ON "users" ("nom");
CREATE INDEX "login_users_key" ON "users" ("login");
CREATE INDEX "modif_users_key" ON "users" ("modif");
CREATE INDEX "nouveau_users_key" ON "users" ("nouveau");
CREATE INDEX "code_users_ukey" ON "users"("code");

/* -------------------------------------------------------- 
  Table structure for table "oldvalue" 
-------------------------------------------------------- */

CREATE TABLE "oldvalue" (
   "id" int4 NOT NULL,
   "nom" varchar(30) NOT NULL,
   "prenom" varchar(30),
   "infos" char(60),
   "login" varchar(8),
   "passwd" varchar(35),
   "code" varchar(32),
   PRIMARY KEY ("id")
);

CREATE INDEX "id_oldvalue_key" ON "oldvalue" ("id");

/* -------------------------------------------------------- 
  Table structure for table "badlogin" 
-------------------------------------------------------- */
CREATE TABLE "badlogin" (
   "nom" varchar(30) NOT NULL,
   PRIMARY KEY ("nom")
);
CREATE INDEX "nom_badlogin_key" ON "badlogin" ("nom");

/* -------------------------------------------------------- 
  Table structure for table "password" 
-------------------------------------------------------- */
CREATE TABLE "password" (
   "id" int4 NOT NULL,
   "md5" varchar(35) NOT NULL,
   "crypt" varchar(35) NOT NULL,
   PRIMARY KEY ("id")
);
CREATE INDEX "id_password_key" ON "password" ("id");


/* default bad login */
INSERT INTO "badlogin" VALUES('root');
INSERT INTO "badlogin" VALUES('bin');
INSERT INTO "badlogin" VALUES('sys');
INSERT INTO "badlogin" VALUES('pgsql');
INSERT INTO "badlogin" VALUES('apache');
INSERT INTO "badlogin" VALUES('mail');
INSERT INTO "badlogin" VALUES('nobody');

/* DROITS */

GRANT ALL on "oldvalue" to hadmin;
GRANT ALL on "users" to hadmin;
GRANT ALL on "classes" to hadmin;
GRANT ALL on "groups" to hadmin;
GRANT ALL on "alias" to hadmin;
GRANT ALL on "badlogin" to hadmin;
GRANT ALL on "password" to hadmin;
